Experienced users may also make use of the many utilities shipping with
instakit: LUT maps, color structs, pipeline processing primitives and 
ink-based separation simulation tools, Enums and wrapper APIs to simplify
PIL's rougher edges – like (say) image modes and compositing - plus other
related miscellany for the enterprising programmer.